# Pinnacle Export

This package was forked from
[Pinnacle-tar-DICOM](https://github.com/AndrewWAlexander/Pinnacle-tar-DICOM).
Many thanks to Andrew Alexander and his colleagues for providing that fantastic
script.

Pinnacle Export generates DICOM objects from raw Pinnacle data.

**Caution: This package is intended for research purposes only and should not
be used clinically!**

## Getting Started

A command line interface is provided for the Pinnacle export tool. For usage,
run:

```
pymedphys pinnacle export -h
```

While the command line tool is useful for testing, it is probably more
convenient to script larger exports. To get started calling this library from
your Python scripts, work off the sample Jupyter notebook, located at
notebooks/pinnacle/ExportSample.ipynb

## Credits

 - Phillip Chlap: University of New South Wales / Liverpool & Macarthur Cancer
 Therapy
 - Andrew Alexander: Saskatchewan Cancer Agency
 - Carsten Brink: University of Southern Denmark / Odense University Hospital
